package
Version:
v0.0.0-...-0c84e95
Opens a new window with list of versions in this module.
Published: Dec 15, 2015
License: GPL-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func DefaultConfig() *configStruct
func ReadConfigFile(filename string) configStruct
Source Files
¶
Click to show internal directories.
Click to hide internal directories.